@@ -14,7 +14,7 @@ SETTINGS = {
 try:
     import django
 except ImportError:
-    django = None
+    djang = None
 
 if django is not None:
     ACTIONKIT_DATABASE_NAME = os.environ['ACTIONKIT_DATABASE_NAME']
